@@ -19,7 +19,7 @@ Usage::
     list_accounts_paginator: ListAccountsPaginator = client.get_paginator("list_accounts")
     list_users_paginator: ListUsersPaginator = client.get_paginator("list_users")
 """
-from mypy_boto3_chime.client import ChimeClient, ChimeClient as Client
+from mypy_boto3_chime.client import ChimeClient as Client, ChimeClient
 from mypy_boto3_chime.paginator import ListAccountsPaginator, ListUsersPaginator
 
 
